﻿/*
 * Copyright (c) 2010-2018 by Daniel Ranft, Wolfgang Hardt, Alexander Strobel
 *   Giegerich & Partner GmbH, Dreieich, Germany
 * Licensed under the MIT License, see LICENSE file for details.
 *
 *
 * Sourcecode: https://www.giepa.de/produkte/gpg4o/gnupgwrapper/
 */

namespace GupGPGWrapper
{
	/// <summary>
	/// List of available commands
	/// </summary>
	public enum Commands
	{
		/// <summary>
		/// Sign data (--clearsign)
		/// </summary>
		Sign,
		/// <summary>
		/// --encrypt
		/// </summary>
		Encrypt,
		/// <summary>
		/// Combine encryption and signature (--sign --encrypt)
		/// </summary>
		SignAndEncrypt,
		/// <summary>
		/// --decrypt
		/// </summary>
		Decrypt,
		/// <summary>
		/// --verify
		/// </summary>
		/// <remarks>
		/// [HACK] If you want to verify a text with a signature file (PGP/MIME),
		/// use the GnuPGWrapper.Originator property for the path to the signature file
		/// </remarks>
		Verify,
		/// <summary>
		/// --list-public-keys
		/// </summary>
		ListPublicKeys,
		/// <summary>
		/// --list-secret-keys
		/// </summary>
		ListSecretKeys,
		/// <summary>
		/// Generate a new keypair with a given config file (--gen-key)
		/// </summary>
		GenerateKey,
		/// <summary>
		/// SignAndEncrypt for files
		/// </summary>
		SignAndEncryptFile,
		/// <summary>
		/// Encrypt for files
		/// </summary>
		EncryptFile,
		/// <summary>
		/// Sign for files
		/// </summary>
		SignFile,
		/// <summary>
		/// Decrypt for files
		/// </summary>
		DecryptFile,
		/// <summary>
		/// Import key from file (--import [file])
		/// </summary>
		ImportKeyFile,
		/// <summary>
		/// Export public key to stdout (--export)
		/// </summary>
		ExportPublicKey,
		/// <summary>
		/// Assume that input[0] is a signature file and verify it
		/// </summary>
		VerifyFile,
		/// <summary>
		/// Delete public key and if available it's secret key (--delete-public-and-secret-key)
		/// </summary>
		DeleteKey,
		/// <summary>
		/// Sign a key
		/// </summary>
		SignKey,
		/// <summary>
		/// Sign a key only on this enviroment (not exportable)
		/// </summary>
		LocalSignKey,
		/// <summary>Adds a new user ID to a keypair</summary>
		/// <remarks>Do NOT use this on a pure public key</remarks>
		AddUserId,
		/// <summary>
		/// Opens the interactive edit-key menu of GnuPG
		/// </summary>
		SetPrimaryUserId,
		/// <summary>
		/// List additional information about the content of the given file
		/// </summary>
		ListPackets,
		/// <summary>
		/// List all containing Keys in a decypted message, need no passphrase
		/// </summary>
		ListEncryptionKeys,
		/// <summary>
		/// List additional information about the content of the given file, but without asking for a passphrase
		/// </summary>
		ListPacketsOnly,
		/// <summary>
		/// Set the ownertrust for a key
		/// </summary>
		TrustKey,
		/// <summary>
		/// Lists the signatures for a key
		/// </summary>
		ListSignatures,
		/// <summary>
		/// Retrieves the gpg version information string (--version)
		/// </summary>
		Version,
		/// <summary>
		/// Enables a key
		/// </summary>
		EnableKey,
		/// <summary>
		/// Disables a key
		/// </summary>
		DisableKey,
		/// <summary>
		/// Exports a secret key
		/// </summary>
		ExportSecretKey,
		/// <summary>
		/// Change the passphrase of a secret key
		/// </summary>
		ChangePassphrase,
		/// <summary>
		/// Changes the expire date of the primary key. Values can be {n}, {n}d, {n}w, {n}m and {n}y, where {n} can be any positive integer.
		/// </summary>
		SetExpireDate,
		/// <summary>
		/// Search for public keys on keyserver
		/// </summary>
		SearchKeys,
		/// <summary>
		/// Receive public keys from keyserver
		/// </summary>
		ReceiveKeys,
		/// <summary>
		/// Send public keys to keyserver
		/// </summary>
		SendKeys,
		/// <summary>
		/// Creates a revocation certificate
		/// </summary>
		CreateRevocationCertificate,
		/// <summary>
		/// Imports ownertrust
		/// </summary>
		ImportOwnertrust,
		/// <summary>
		/// Exports ownertrust
		/// </summary>
		ExportOwnertrust,
		/// <summary>
		/// Imports a revocation certificate
		/// </summary>
		ImportRevocationCertificate,
		/// <summary>
		/// Lists the configuration (things configured in gpg.conf etc...)
		/// </summary>
		ListConfig,
		/// <summary>
		/// Updates a weak signed key's self-signatures to SHA2
		/// </summary>
		ReSignWeakSignedKey,
		/// <summary>
		/// Adds a new subkey
		/// </summary>
		AddSubKey,
		/// <summary>
		/// Start Menu for editing a key and his subkeys
		/// </summary>
		EditKey
	};

	/// <summary>
	/// Available verbose levels
	/// </summary>
	public enum VerboseLevel
	{
		/// <summary>
		/// Not verbose (no additional information will be listed)
		/// </summary>
		NoVerbose,
		/// <summary>
		/// List some more information about, what gpg is doing
		/// </summary>
		Verbose,
		/// <summary>
		/// List detailed information about, that gpg is doing (for the real crazy people)
		/// </summary>
		VerboseVerbose
	};
}
